summaryrefslogtreecommitdiff
path: root/lib/Analysis/DataStructure/DataStructure.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'lib/Analysis/DataStructure/DataStructure.cpp')
-rw-r--r--lib/Analysis/DataStructure/DataStructure.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/Analysis/DataStructure/DataStructure.cpp b/lib/Analysis/DataStructure/DataStructure.cpp
index 800c82ad98..6bc5a716fc 100644
--- a/lib/Analysis/DataStructure/DataStructure.cpp
+++ b/lib/Analysis/DataStructure/DataStructure.cpp
@@ -248,9 +248,9 @@ void DSGraph::markIncompleteNodes() {
markIncompleteNode(Args[i]);
}
// Mark all of the nodes pointed to by global nodes as incomplete...
for (unsigned i = 0, e = Nodes.size(); i != e; ++i)
- if (Nodes[i]->NodeType & DSNode::GlobalNode) {
+ if (Nodes[i]->NodeType & (DSNode::GlobalNode | DSNode::CastNode)) {
DSNode *N = Nodes[i];
for (unsigned i = 0, e = N->getNumLinks(); i != e; ++i)
markIncompleteNode(N->getLink(i));
@@ -248,9 +248,9 @@ void DSGraph::markIncompleteNodes() {
markIncompleteNode(Args[i]);
}
- // Mark all of the nodes pointed to by global nodes as incomplete...
+ // Mark all of the nodes pointed to by global or cast nodes as incomplete...
for (unsigned i = 0, e = Nodes.size(); i != e; ++i)